This module hosts all predefined workflows. You can think of this module as the alternative to Atomate, where instead of the FireWorks manager, we use Prefect. We also put a heavy emphasis on ETL (extract, transform, load) workflow structure to ensure our future workflows will have minimal negative engineering (I should add my discussion of fractured vs. fixed workflow architecture here in this README. I intend for this to be where beginner users start -- either here or start with the website test-server user interface. I will certainly split this module into submodules, such as 'final' (or should I just have the highest-level flow classes here or in a folder like 'diffusion' or 'population_analysis'?), 'tasks.extract/transform/load', 'execution.local/dask/fireworks/prefect', or something similar.